@@ -1,4 +1,4 @@
-from django.core.management.base import BaseCommand
+from django.core.management.base import BaseCommand, CommandError
 from django.conf import settings
 from _generate_debugger import generate_debugger
 
@@ -8,6 +8,8 @@ class Command(BaseCommand):
     help = 'Adds a debugger config that overrides console log with angular.$log'
 
     def handle(self, *args, **options):
+        if not args:
+            raise CommandError('Need to add a password argument')
         for password in args:
             self.stdout.write('Generating debugger')
             if hasattr(settings, 'BASE_DIR'):
