@@ -12,6 +12,6 @@ class Command(BaseCommand):
             dir = settings.BASE_DIR
         else:
             dir = '.'
-        for service_name in args:
-            generate_controller(dir, service_name)
-            self.stdout.write('Successfully initialized service "%s"' % service_name)
+        for controller_name in args:
+            generate_controller(dir, controller_name)
+            self.stdout.write('Successfully initialized service "%s"' % controller_name)
